@@ -6,32 +6,27 @@ import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.font.FontRenderContext;
 import java.awt.geom.Rectangle2D;
-import java.text.DecimalFormat;
+import java.util.Collection;
+import java.util.Hashtable;
 
 import org.af.commons.images.GraphDrawHelper;
 import org.af.commons.images.GraphException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.mutoss.config.Configuration;
-import org.mutoss.gui.RControl;
 
 public class Edge {
 
 	private static final Log logger = LogFactory.getLog(Edge.class);
 	public boolean curve = false;
-	static DecimalFormat format = new DecimalFormat("#.###");
-	static DecimalFormat formatSmall = new DecimalFormat("#.###E0");
 	FontRenderContext frc = null;
 	Graphics2D g2d;
 	int k1, k2;
 	public Node to;
-
 	public Node from;
 	
 	VS vs;
 	
-	private Double w;
-	private String stringW = "";
+	EdgeWeight ew;
 
 	public Edge(Node von, Node nach, Double w, VS vs) {		
 		int x1, x2, y1, y2;
@@ -43,8 +38,7 @@ public class Edge {
 		k2 = y1 + (y2-y1)/4; //(y1+y2)/2;
 		this.from = von;
 		this.to = nach;
-		this.w = w;
-		calculateWeightString();
+		this.ew = new EdgeWeight(w);
 		this.vs = vs;
 	}
 	
@@ -84,8 +78,7 @@ public class Edge {
 	public Edge(Node von, Node nach, Double w, VS vs, int k1, int k2) {
 		this.from = von;
 		this.to = nach;
-		this.w = w;
-		calculateWeightString();
+		this.ew = new EdgeWeight(w);
 		this.vs = vs;
 		this.k1 = k1;
 		this.k2 = k2;
@@ -154,17 +147,12 @@ public class Edge {
 		}
 	}
 
-	public Double getW() {
-		return w;
-	}
+	/*public Double getW() {
+		return ew.;
+	}*/
 
-	private String getWS() {		
-		if (w.toString().equals("NaN")) return "ε";
-		if (w<0.0009) {
-			return formatSmall.format(w);
-		} else {
-			return stringW;			
-		}
+	String getWS() {		
+		return ew.toString();
 	}
 
 	public boolean inYou(int x, int y) {
@@ -241,39 +229,28 @@ public class Edge {
 	}
 
 	public void setW(Double w) {
-		this.w = w;
-		calculateWeightString();
+		ew = new EdgeWeight(w);
 		vs.nl.repaint();
 	}
-
-	// TODO Call this method when options change!
-	public void calculateWeightString() {
-		stringW = getString();		
+	
+	public void setW(String text) {
+		ew = new EdgeWeight(text);
+		vs.nl.repaint();		
 	}
 
-	private String getString() {
-		if (!Configuration.getInstance().getGeneralConfig().showFractions()) {
-			return format.format(w);
-		} else {
-			String f = RControl.getFraction(w);
-			if (f.equals("1/2")) return("½");
-			if (f.equals("1/3")) return("⅓");
-			if (f.equals("2/3")) return("⅔");
-			if (f.equals("1/4")) return("¼");
-			if (f.equals("3/4")) return("¾");
-			/* The following do often not work:
-			if (f.equals("1/5")) return("⅕");
-			if (f.equals("2/5")) return("⅖");
-			if (f.equals("3/5")) return("⅗");
-			if (f.equals("4/5")) return("⅘");
-			if (f.equals("1/6")) return("⅙");
-			if (f.equals("5/6")) return("⅚");
-			if (f.equals("1/8")) return("⅛");
-			if (f.equals("3/8")) return("⅜");
-			if (f.equals("5/8")) return("⅝");
-			if (f.equals("7/8")) return("⅞");*/
-			return f;
-		}
+	public String getWLaTeX() {		
+		return ew.getLaTeXStr();
 	}
 
+	public Collection<String> getVariable() {
+		return ew.getVariables();
+	}
+
+	public double getWeight(Hashtable<String,Double> ht) {
+		return getWeight(ht);
+	}
+
+	public double getW(Hashtable<String, Double> ht) {
+		return ew.getWeight(ht);
+	}
 }
