@@ -4,6 +4,8 @@ import java.awt.Color;
 import java.awt.Component;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
+import java.awt.event.KeyEvent;
+import java.awt.event.KeyListener;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Vector;
@@ -11,6 +13,7 @@ import java.util.Vector;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
+import javax.swing.JTextField;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -19,7 +22,7 @@ import org.mutoss.config.Configuration;
 import com.jgoodies.forms.layout.CellConstraints;
 import com.jgoodies.forms.layout.FormLayout;
 
-public class PView extends JPanel {
+public class PView extends JPanel implements KeyListener {
 
 	JLabel statusBar;
 	private static final Log logger = LogFactory.getLog(PView.class);
@@ -27,7 +30,10 @@ public class PView extends JPanel {
 	private Vector<PPanel> panels = new Vector<PPanel>();
 	CellConstraints cc = new CellConstraints();	
 	//JPanel panel = new JPanel();
-	JLabel label = new JLabel("Total α: "+0);
+	JLabel label = new JLabel("");
+	JLabel weightLabel = new JLabel("Weight");
+	JLabel alphaLabel = new JLabel("Total α: ");
+	JTextField totalAlpha = new JTextField("0.05");
 	GridBagConstraints c = new GridBagConstraints();
 	
 	public PView() {  
@@ -36,6 +42,8 @@ public class PView extends JPanel {
 		c.weightx=1; c.weighty=1; c.fill = GridBagConstraints.BOTH;
 		c.gridx=0; c.gridy=0; c.gridwidth = 1; c.gridheight = 1; c.ipadx=0; c.ipady=0;
 		
+		totalAlpha.addKeyListener(this);
+		
 		setUp();
     }
 	
@@ -79,7 +87,7 @@ public class PView extends JPanel {
 		JPanel panel = new JPanel();
 		
 		String cols = "5dlu, fill:pref:grow, 5dlu, fill:pref:grow, 5dlu, fill:pref:grow, 5dlu, fill:pref:grow, 5dlu";
-        String rows = "5dlu, pref, 5dlu, pref, 5dlu";
+        String rows = "5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu";
         for (PPanel p : panels) {
         	rows += ", pref, 5dlu";
         }
@@ -89,7 +97,7 @@ public class PView extends JPanel {
 		
     	panel.add(new JLabel("Hypothesis"), cc.xy(2, 2));
     	
-    	panel.add(new JLabel("α Level"), cc.xy(4, 2));
+    	panel.add(weightLabel, cc.xy(4, 2));
     	//panel.add(new JLabel("Signif. Level"), cc.xy(4, 2));
 
     	panel.add(new JLabel("P-Value"), cc.xy(6, 2));
@@ -104,6 +112,10 @@ public class PView extends JPanel {
 			row += 2;
 		}
 		panel.add(label,cc.xyw(2, row, 7));
+		row += 2;
+		panel.add(alphaLabel, cc.xy(2, row));    	
+    	panel.add(totalAlpha, cc.xy(4, row));
+		
 		panel.revalidate();
 		removeAll();
 		add(new JScrollPane(panel), c);
@@ -116,10 +128,10 @@ public class PView extends JPanel {
 				alpha += p.w;
 			}
 		}
-		String text = "Total α: "+Configuration.getInstance().getGeneralConfig().getDecFormat().format(alpha);
-		if (alpha>=1) {
+		String text = "Sum of weights: "+Configuration.getInstance().getGeneralConfig().getDecFormat().format(alpha);
+		if (alpha>1) {
 			label.setForeground(Color.RED);
-			text += "; The total α is greater or equal 1!";
+			text += "; The total weight is greater 1!";
 		} else {
 			label.setForeground(Color.BLACK);
 		}
@@ -156,7 +168,13 @@ public class PView extends JPanel {
 	public void setTesting(boolean b) {
 		PPanel.setTesting(b);
 		for (PPanel p : panels) {
-			p.keyTyped(null);
+			p.updateMe(true);
+		}
+		totalAlpha.setEditable(!b);
+		if (b) {
+			weightLabel.setText("α Level");
+		} else {
+			weightLabel.setText("Weight");
 		}
 	}
 
@@ -177,5 +195,19 @@ public class PView extends JPanel {
 		}
 		throw new RuntimeException("Something happend that should never happen. Please report!");
 	}
+
+	public double getTotalAlpha() {
+		return Double.parseDouble(totalAlpha.getText());
+	}
+
+	public void keyPressed(KeyEvent e) {keyTyped(e);}
+
+	public void keyReleased(KeyEvent e) {keyTyped(e);}
+
+	public void keyTyped(KeyEvent e) {
+		for (PPanel p : panels) {
+			p.updateMe(false);
+		}
+	}
 	
 }
